"""Bundled sample data for documentation examples.

This package contains cached weather data files for stations used in
documentation examples. This allows documentation to be built without
network access to NOAA servers.

Included stations:
- 744860-94789 (JFK Airport, New York)
- 725030-14732 (LaGuardia Airport, New York)
- 724050-13743 (Washington Reagan Airport)
"""
